capture log close
set more off
clear

log using "~/dropbox/wsp/programs/common-v3-2012-01-03/0 EXAMPLE-peru.log", text replace
* EXAMPLE-peru.do
* template to run all common modules and merge them into 
* a derived variable dataset at each level of the data
* (household, child, caregiver, structured observation)
*
* The programs assume you are running them on a panel dataset with
* baseline and endline data.  Some of the programs require a variable
* called "survid", with 1=Baseline and 2=Endline to differentiate 
* between survey rounds.
*
* Example based on the Peru datasets.

* To run the programs, modify the local macros in the INPUT
* section, below
* 
* Due to the WHO anthropometric Z-score algorithm, it is
* recommended that you run this in a fresh session of Stata.


*--------------------------------------------
* INPUT
* Specify file directories and file names
*--------------------------------------------

* data files: 
* household, child, caregiver, SO
*
local hhdata "~/dropbox/wsp/peru/data/untouched/long/hhold-panel.dta"
local chdata "~/dropbox/wsp/peru/data/untouched/long/child-panel.dta"
local cgdata "~/dropbox/wsp/peru/data/untouched/long/cgiver-panel.dta"
local sodata "~/dropbox/wsp/peru/data/untouched/endline/SO.dta"

* ID variables to use as household / person keys
* could be a single variable to identify unique HHs or people + survey round
* -- just needs to be a unique key
local cluster "pewsp_id1 survid"
local hhids "pewsp_id1 pewsp_id2 survid"
local pids  "pewsp_id1 pewsp_id2 id survid"

* Hemoglobin level variable
* (name may differ by country, depending on whether altitude adjustment is required)
* g33_14 (no alt adjustment), g33_14b (w/ alt adjustment) 
local hbvar "g33_14b" 

* Output file directory
local outdir "~/dropbox/wsp/peru/data/temp"

* Prefix for output file names (e.g., country name)
local prefix "Peru"

* Directory with WHO i-growup reference data 
* (included with the common variable program distribution)
* (for anthropometric Z-score calculation)
local whodir "~/dropbox/wsp/programs/common-v3-2012-01-03/3 who-igrowup"

* Directory that includes programs to calculate derived variables
local pgdir "~/dropbox/wsp/programs/common-v3-2012-01-03"


*--------------------------------------------
* Load programs to calculate derived variables
*--------------------------------------------
qui do "`pgdir'/0 wsp-tolower.do"
qui do "`pgdir'/1 wsp-date-age-sex.do"
qui do "`pgdir'/2 wsp-illness.do"
qui do "`pgdir'/3 wsp-anthro.do"
qui do "`pgdir'/4 wsp-ASQ-bl.do"
qui do "`pgdir'/4 wsp-ASQ-el.do"
qui do "`pgdir'/5 wsp-anemia.do"
* group 6 not completed
qui do "`pgdir'/7 wsp-sanitation.do"
qui do "`pgdir'/8 wsp-water.do"
qui do "`pgdir'/9 wsp-hygiene-hh-Peru.do"
qui do "`pgdir'/10 wsp-hygiene-caregiver.do"
qui do "`pgdir'/11 wsp-structured-obs.do"
* group 12 not completed


*--------------------------------------------
* Convert variable names to lower case
*--------------------------------------------
use `hhdata', clear
tolower *
sort `hhids'
tempfile hhdata2
save `hhdata2'

use `chdata'
tolower *
sort `pids'
tempfile chdata2
save `chdata2'

use `cgdata'
tolower *
sort `pids'
tempfile cgdata2
save `cgdata2'

use `sodata'
tolower *
sort `pids'
tempfile sodata2
save `sodata2'


*--------------------------------------------
* Peru-specific dataset standardization
*--------------------------------------------

use `hhdata2', clear

** rename water source variables to be consistent
rename g07a_01 g07_01
	label copy G07A_01 G07_01
	label values g07_01 G07_01
rename g07a_06c g07_06c
	label copy G07A_06C G07_06C
	label values g07_06c G07_06C
rename g07a_07 g07_07
	label copy G07A_07 G07_07
	label values g07_07 G07_07

* convert water treatment variable from string to numeric
forvalues i = 1/7 {
	gen v`i' = real(g08_05_`i')
	local vlab : var lab g08_05_`i'
	drop g08_05_`i'
	rename v`i' g08_05_`i'
	label var g08_05_`i' "`vlab'"
}

* rename water treatment variables to standard convention
forvalues i = 1/7 {
	rename g08_06a_`i' g08_06_`i'
}

save `hhdata2', replace


*--------------------------------------------
* 1 dates, age sex
*--------------------------------------------

wspdateage, idvars(`pids') mergevars(`hhids') clusterid(`cluster') hhfile(`hhdata2') chfile(`chdata2') outfile("`outdir'/`prefix'-dateage.dta")

* merge age / sex information back to the child
* data because the age in days is needed repeatedly
* in the calculations below (as is sex)

keep `pids' intdate birthdate ageday agemth sex
sort `pids'

qui merge `pids' using `chdata2'
assert _merge!=2
drop _merge

save `chdata2', replace



*--------------------------------------------
* 2 Illness
*--------------------------------------------
use `chdata2', clear
wspillness, idvars(`pids') outfile("`outdir'/`prefix'-illness.dta")


*--------------------------------------------
* 3 anthropometric Z-scores
*--------------------------------------------
use `chdata2', clear
wspanthro, idvars(`pids') whodir(`whodir')  outdir(`outdir') outfile("`prefix'-anthro.dta")


*--------------------------------------------
* 4 ASQ Baseline + Endline
*--------------------------------------------
use `chdata2', clear
keep if survid == 1
wspASQbl, idvars(`pids') outfile("`outdir'/`prefix'-ASQbl.dta")

use `chdata2', clear
keep if survid == 2
wspASQel, idvars(`pids') outfile("`outdir'/`prefix'-ASQel.dta")

* now append baseline + endline datasets
use "`outdir'/`prefix'-ASQbl.dta", clear
append using "`outdir'/`prefix'-ASQel.dta"
sort `pids'
save "`outdir'/`prefix'-ASQ.dta", replace

*--------------------------------------------
* 5 Anemia
*--------------------------------------------
use `chdata2', clear
wspanemia, idvars(`pids') hbvar(`hbvar') outfile("`outdir'/`prefix'-anemia.dta")


*--------------------------------------------
* 6 water and stool microbiology
*--------------------------------------------
* Not complete

*--------------------------------------------
* 7 sanitation
*--------------------------------------------
use `hhdata2', clear
wspsanitation, idvars(`hhids') outfile("`outdir'/`prefix'-sanitation.dta")


*--------------------------------------------
* 8 water
*--------------------------------------------
use `hhdata2', clear
wspwater, idvars(`hhids') outfile("`outdir'/`prefix'-water.dta")


*--------------------------------------------
* 9 hygiene and handwashing, HH
*--------------------------------------------

use `hhdata2', clear
wsphygienehh,  idvars(`hhids') outfile("`outdir'/`prefix'-hygienehh.dta")


*--------------------------------------------
* 10 hygiene and handwashing, Caregiver
*--------------------------------------------
use `cgdata2', clear
wsphygienecg,  idvars(`pids') outfile("`outdir'/`prefix'-hygienecg.dta")


*--------------------------------------------
* 11 Structured Observation Data
*--------------------------------------------
use `sodata2', clear
wspSO, idvars(`pids') outfile("`outdir'/`prefix'-SO.dta")


*--------------------------------------------
* Merge together Household level variables
* into a single dataset
*--------------------------------------------

use "`outdir'/`prefix'-sanitation.dta", clear

sort `hhids'
merge `hhids' using "`outdir'/`prefix'-water.dta"
assert _merge == 3
drop _merge

sort `hhids'
merge `hhids' using "`outdir'/`prefix'-hygienehh.dta"
assert _merge == 3
drop _merge

label data "Household Level Derived Variables, WSP IE"
sort `hhids'
save "`outdir'/`prefix'-derived-hh.dta", replace

*--------------------------------------------
* Merge together Child level variables
* into a single dataset
*--------------------------------------------

use "`outdir'/`prefix'-dateage.dta", clear

sort `pids'
merge `pids' using "`outdir'/`prefix'-illness.dta"
assert _merge==3
drop _merge

sort `pids'
merge `pids' using "`outdir'/`prefix'-anthro.dta"
tab _merge
assert _merge!=2
drop _merge

sort `pids'
merge `pids' using "`outdir'/`prefix'-ASQ.dta"
tab _merge
assert _merge!=2
drop _merge g25*

sort `pids'
merge `pids' using "`outdir'/`prefix'-anemia.dta"
assert _merge==3
drop _merge


label data "Child Level Derived Variables, WSP IE"
sort `hhids'
save "`outdir'/`prefix'-derived-ch.dta", replace

*--------------------------------------------
* Merge together Caregiver level variables
* into a single dataset
* NOTE: no merge currently required
*--------------------------------------------
use "`outdir'/`prefix'-hygienecg.dta", clear
sort `pids'

label data "Caregiver Level Derived Variables, WSP IE"
sort `pids'
save "`outdir'/`prefix'-derived-cg.dta", replace



log close
exit
