
*---------------------------------------------
* Program    : 1 wsp-date-age-sex.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 2.0 (2011-09-09)


A general program to calculate a few standard
dates and ages for the WSP IE endline datasets.

The program requires more arguments than most
because it requires information from both the
household and child level datasets.

The program creates a standard interview date,
birth date for each child, and calculated age
(in days) based on the difference between the
two dates. 

The program imputes missing interview dates
with the median for the cluster.

The program estimates the age in days for 
children with missing birth dates by using
reported age information (in years/months) 
from the survey respondent.  

The program requires that the user specify
the file for the household level data and
the child level data.  The household level
data are needed to obtain an interview date.


Arguments:
idvars()    : Variable name list of identifier variables required to identify unique children

mergevars() : Variable name list of identifier variables required to merge the household file to the child file. This could be a subset of the idvars() argument

clusterid() : Variable that identifies unique clusters

hhfile()  : Text string for a directory/filename of the household file (likely called "hhold.dta")

chfile()  : Text string for a directory/filename of the child file (likely called "child.dta")

outfile()   : Text string for a directory/filename for the output dataset


*/
*---------------------------------------------

capture program drop wspdateage
program define wspdateage
version 10

syntax , idvars(varlist) mergevars(varlist) clusterid(varlist) hhfile(string) chfile(string) outfile(string)


*---------------------------------------------
* Load the child-level dataset
*---------------------------------------------

use "`hhfile'", clear

di as res _n "Calculating interview dates..."

* Interview Date
gen intdate = mdy(month,day,year)
	label var intdate "Interview date"
	format intdate %d
	
di as res _n "Imputing missing interview dates with the cluster median..."

sort `clusterid'
by `clusterid': egen meddate = median(intdate)
replace intdate = meddate if intdate == .

keep `mergevars' intdate
sort `mergevars'
tempfile hhdata
save `hhdata'


*---------------------------------------------
* Merge interview dates to the child dataset
*---------------------------------------------

di as res _n "Merging interview dates to the child file..."

use "`chfile'", clear
sort `mergevars'
merge `mergevars' using `hhdata'

qui count if _merge==1
local nochmatch = r(N)
if (`nochmatch>0') {
	di as res _n "WARNING: There are `nochmatch' children that do not match the household file. This is their ID information:"
	list `idvars' if _merge==1, clean
	di _n _n
}
drop if _merge == 2
drop _merge




*---------------------------------------------
* Calculate child age
*
* For birth date,
* if the day of the month is unknown, then
* assume:
* (1) it is the 15th, unless the child < 1 mo
* (2) assume it is the 1st if the child is < 1mo
*---------------------------------------------


capture drop birthdate ageday agemth
	
gen birthdate = mdy(g01_04m,g01_04d,g01_04y)

	replace birthdate = mdy(g01_04m,15,g01_04y) if (birthdate==. & inlist(g01_04d,-99,99,.) & g01_04m >=1)

	replace birthdate = mdy(g01_04m,1,g01_04y) if (birthdate==. & inlist(g01_04d,-99,99,.) & g01_04m <=1)
	
	replace birthdate = . if (g01_04m== -99) & (g01_04d== -99) & (g01_04y==9999)
	
	label var birthdate "Birth date"
	format birthdate %d

gen ageday = (intdate-birthdate)
	label var ageday "Age in days"

gen agemth = ageday / 30.4375
	label var agemth "Age in months"
	
	
* calculate alternate age in months for children w/ missing birth dates
gen agemth2 = g01_05y * 12 + g01_05m
	replace agemth2 = . if (g01_05y == -99) & (g01_05m == -99)

gen agediff = agemth - agemth2
qui count if agediff > 1.5
local dcount = r(N)
di as res _n "There are `dcount' children with ages in months that differ > 1.5 months between data in Qs G04 and G05" _n _n  "Data in G04 are prioritized"

replace agemth = agemth2 if agemth <0 | agemth == .
drop agemth2 agediff

replace ageday = agemth * 30.4375 if (ageday==. & agemth!=.)


*---------------------------------------------
* Identify child sex (1=male, 2=female)
*---------------------------------------------
gen sex = g01_02
	replace sex = . if g01_02 == .
	label define sex 1 "Male" 2 "Female"
	label values sex sex
	label var sex "Sex"

*---------------------------------------------
* Output the dataset with the added variables
*---------------------------------------------

di as res _n "Compressing and saving data..."
keep `idvars' `mergevars' intdate birthdate ageday agemth sex g01_02 g01_04* g01_05*

label data "Standard Dates, Ages and Sex for Children"

save "`outfile'", replace

codebook, c

end wspdateage




