
*---------------------------------------------
* Program    : 2 wsp-illness.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 2.0 (2011-09-09)

A general program for the WSP IE to calculate
acute illness from the child health calendar.
It creates a set of indicator variables for
each symptom collected in the calendar for days
0 (day of the survey) to day 7 of recall.
(note: in the endline dataset, daily records
only exist back 7 days)

The program creates derived variables for 
diarrhea (based on a symptom definition)
acute respiratory infections (ARI)
acute lower respiratory infections (ALRI)
(definitions below)

Finally, the program creates measures of 2, 7, and 
14 day period prevalence for diarrhea, ARI, and ALRI,
as well as 2d and 7d period prevalences for a few of 
the individual symptoms
(fever, cough, coryza, brusing, itchy skin)

NOTE: This program is designed to run on the endline data 
format. 


--
Derived variable definitions:
--

Diarrhea is defined as 3+ loose/watery stools in
24 hours OR a single stool with blood/mucus 

Baqui, A. H.; Black, R. E.; Yunus, M.; Hoque, A. R.; Chowdhury, H. R. & Sack, R. B. Methodological issues in diarrhoeal diseases epidemiology: definition of diarrhoeal episodes. Int J Epidemiol, 1991, 20, 1057-1063

--

ARI and ALRI are defined per the WHO IMCI guidelines.
ARI is defined as (persistent cough OR difficulty breathing).
ALRI is defined as (persistent cough OR difficulty breathing) AND a raised respiratory rate
> 60 breaths per min for children < 60 days
> 50 breaths per min for children 60 - 364 days
> 40 breaths per min for children 365 days - 60 months

Gove, S. Integrated management of childhood illness by outpatient health workers: technical basis and overview. The WHO Working Group on Guidelines for Integrated Management of the Sick Child Bull World Health Organ, 1997, 75 Suppl 1, 7-24

--

The program requires the full set of variables from Module 19 and
variable G20_03 (breathing pace) from Module 20.  

Beyond these modules, the program requires that the 
dataset include two additional variables:
   ageday : child's age in days
   survid : survey ID, equal to 1 for baseline and 2 for endline

The program does not clean the datasets for
any potential errors in the data. 
   
The program creates a summary dataset with
identifiers. It creates the dataset in the 
specified directory (see arguments)

Arguments:
idvars()  : Variable name list of Identifier variables to keep in the dataset. If running on panel data, then this must also include an indicator for survey round

outfile() : Text string for a directory/filename for the output dataset


*/
*---------------------------------------------



capture program drop wspillness
program define wspillness
version 10
	* this program calculates child symptoms and acute illness
	* it is written to be run on WSP IE endline data
	* it requires variables from modules 19 and 20
	* additionally, it requires two variables
	*  agedays : age of child in days
	*  survid  : survey ID, equal to 1 for baseline & 2 for endline

syntax, idvars(varlist) outfile(string)


di as res _n "--------------------------------" _n "* Begin wspillness" _n "--------------------------------"

*---------------------------------------------
* Retrieve the health calendar data and
* health calendar summary
*---------------------------------------------

*--------------------------------------------
* format symptom data by day
*--------------------------------------------

di as res _n "Creating variables..." _n

capture drop fever* cough* coryza* breath* cramps* nausea* vomit* threed* soft* blood* noeat* bruise* itch*

local symps "fever cough coryza breath cramps nausea vomit threed soft blood noeat bruise itch"
local sn "01 02 03 04 05 06 07 08 09 10 11 12 13"
local dd "00 01 02 03 04 05 06 07 08 09 10 11 12 13 14"
local ds "0 1 2 3 4 5 6 7"
local i = 1
foreach symp of local symps {
	local sid = word("`sn'",`i')
	foreach day of local dd {
		gen byte `symp'`day' = g19_`sid'd`day'=="1"
		replace `symp'`day' = . if g19_`sid'd`day'=="-55"
		label var `symp'`day' "`symp', day `day'"
	}
	local i = `i' + 1
}


*--------------------------------------------
* Create symptom-based diarrhea definition
*--------------------------------------------
capture drop diar*

*** identify diarrhea based on symptom definitions
*** [>= 3 stools/day (g19_08) AND loose/water stool (g19_09) ] OR [blood/mucus in stool (g19_10)]

local days "00 01 02 03 04 05 06 07 08 09 10 11 12 13 14"
foreach day of local days {
	gen byte diar`day' = (threed`day'==1 & soft`day'==1) | (blood`day'==1)
	qui replace diar`day' = . if (threed`day'==. & soft`day'==. & blood`day'==.)
	label var diar`day' "diarrhea, day `day'"
}

*-------------------------------------------
* WHO guidelines for raised respiratory rates in children < 5
* >60 per min for under 60 days old
* >50 per min for aged 60 – 364 days
* >40 for aged 1 – 5 years
*-------------------------------------------
gen bpm = g20_03*2
	label var bpm "Breaths per minute (G20_03*2)"
	replace bpm = . if bpm < 20

gen bpmelev = 1 if (bpm>60 & ageday<60) & bpm < .
 replace bpmelev = 1 if (bpm>50 & ageday >=60 & ageday <365) & bpm < .
 replace bpmelev = 1 if (bpm>40 & ageday >=365 & ageday <1826) & bpm < .
 replace bpmelev = 0 if bpm < . & bpmelev == .
 label var bpmelev "WHO def Elevated breath rate"


capture drop ari*
*** identify Acute Respiratory Infections (ARI) based on symptom definitions
*** [constant cough (g19_02) OR difficulty breathing (g19_04)]

local days "00 01 02 03 04 05 06 07 08 09 10 11 12 13 14"
foreach day of local days {
	gen byte ari`day' = (cough`day'==1 | breath`day'==1)
	replace ari`day' = . if (cough`day'==. & breath`day'==.)
	label var ari`day' "acute resp. inf. day `day'"
}


capture drop alri*
*** identify Acute Lower Respiratory Infections (ALRI) based on symptom definitions
*** [constant cough (g19_02) OR difficulty breathing (g19_04)] AND [raised respiratory rate (g20_03)]

local days "00 01 02 03 04 05 06 07 08 09 10 11 12 13 14"
foreach day of local days {
	gen byte alri`day' = (cough`day'==1 | breath`day'==1) & (bpmelev==1)
	replace alri`day' = . if (cough`day'==. & breath`day'==.)
	label var alri`day' "acute lower resp. inf. day `day'"
}



*--------------------------------------------
* calculate period prevalence for recall windows
* 2 days, 7 days, 14 days
* day of the interview is excluded
*--------------------------------------------

di as res _n "Calculating period prevalence measures..." _n

local vlist "diar ari alri fever cough coryza bruise itch"
local dd "02 07 14"
foreach var of local vlist {
	foreach day of local dd {
		egen byte `var'`day'pp = rowmax(`var'01 - `var'`day')
		label var `var'`day'pp "`var' period prev, last `day' days"		
	}
}

* calculate 14 day period prevalences for main health outcomes
* in the endline data: health calendar only goes back 7d in the 
* endline survey so must use the filter question

replace diar14pp = 1 if survid == 2 & (g19_08==1 & g19_09==1) | (g19_10==1)

replace ari14pp = 1 if survid == 2 & (g19_02==1 | g19_04==1)

replace alri14pp = 1 if survid == 2 & (g19_02==1 | g19_04==1) & (bpmelev==1)


*--------------------------------------------
* Improve some of the variable labels for clarity
*--------------------------------------------
local dd "00 01 02 03 04 05 06 07 08 09 10 11 12 13 14"
foreach d of local dd {
	label var cough`d' "constant cough, day `d'"
	label var coryza`d' "coryza/congestion, day `d'"
	label var breath`d' "difficulty breathing, day `d'"
	label var cramps`d' "stomach cramps, day `d'"
	label var threed`d' "3+ stools in 24 hrs, day `d'"
	label var soft`d' "soft or watery stool, day `d'"
	label var blood`d' "blood or mucus in stool, day `d'"
	label var noeat`d' "refused to eat, day `d'"
	label var bruise`d' "bruising/abrasions, day `d'"
	label var itch`d' "itchy skin/scalp, day `d'"
	
}


di as res _n "Compressing dataset..."
keep `idvars' fever00 - alri14pp
order `idvars' bpm bpmelev
compress 



*---------------------------------------------
* Output an acute illness dataset
*---------------------------------------------

label data "Acute Child Illness"
sort `idvars'
codebook, c

save "`outfile'", replace


di as res _n "--------------------------------" _n "* End wspillness" _n "--------------------------------"
end wspillness


