
*--------------------------------------------
* Program    : 3 wsp-anthro.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 1.0 (2011-07-12)

This program calculates anthropometric Z-scores
for length/height, weight, weight-for-height,
head circumference, and mid-upper arm circumference.

This program *does not clean* the datasets
for potential outliers. The program flags children
with Z-scores that fall beyond plausible bounds.
Measurement errors that lead to outliers 
can originate in the anthropometric measures,
age, or interview date.  If outliers are used
to further clean the data, then the dataset
should be cleaned and then this program re-run
on the cleaned data.

The program calculates Z-scores based on the
2006 WHO Reference Standards, and requires
a set of standard datasets and Stata .ado files
downloaded from the WHO.  The website for 
dowload is:
http://www.who.int/childgrowth/software/en/

and the directory will be distributed with this
program.

The Stata code distributed by WHO is poorly written
in both how it handles local macros and how it 
vectorizes code.  Because of the poor lexical 
scoping with the local macro variables in WHO Anthro, 
it is best to run this code on a new session of 
Stata that has not had any local macros defined 
(else you may get an error -- though I haven't
encountered this problem often running Stata v10).

In addition to the underlying WHO datasets
this program requires the following variables
as input:


sex     (MUST be 1=male 2=female for macro)
ageday  Child age in days

g33_05  Weight if the child in kg
g33_06  Indicator that child was weighed in mother's arms
g33_07  Weight of the mother in kg
g33_09  Length/height in cm
g33_10  Mid-upper arm circumference in cm
g33_11  Head circumference in cm
g33_12  Result of the height measurement

The program creates a summary dataset with
identifiers along with the age and 
anthropometry information.  It creates the
dataset in the specified directory (see arguments)

Arguments:
idvars()  : Variable name list of Identifier variables to keep in the dataset. If running on panel data, then this must also include an indicator for survey round

whodir()  : Text string that identifies the directory for the WHO igrowup macro and underlying datasets

outdir()  : Text string that identifies the output directory

outfile() : Text string filename for the output dataset
*/
*
* Major updates to the code:
*
*--------------------------------------------

capture program drop wspanthro
program define wspanthro
version 10
syntax , idvars(varlist) whodir(string) outdir(string) outfile(string)


* calculate child wgtght in kg
* (net out mother's wgtght if weighed in arms
gen double wgt = g33_05
	replace wgt = . if wgt<=0
	replace wgt = (g33_05 - g33_07) if ( (g33_06==2) & (g33_05 - g33_07)>0 )
	label var wgt "Child weight (to 0.1 kg)"
	
* height (and flag for standing / lying)
gen double hgt = g33_09
	replace hgt = . if hgt <=0
	label var hgt "Child height (to 0.1 cm)"
gen byte hgtmes = g33_12
	label var hgtmes "Height measurement result"
	label values hgtmes G33_12
	
	* recode height measurement if a measure exists
	* (assumes lying if the child is < 24 months / 731 days)
	replace hgtmes = 2 if ( (hgtmes==-98) & (hgt>0 & hgt<.) & ageday<731 )
	replace hgtmes = 1 if ( (hgtmes==-98) & (hgt>0 & hgt<.) & ageday>=731 )

* arm and head circumference
gen double uac = g33_10
	replace uac = . if uac <=0
	label var uac "Child arm circ. (to 0.1 cm)"
gen double headc = g33_11
	replace headc = . if headc <=0
	label var headc "Child head circ. (to 0.1 cm)"
	
	
*---------------------------------------------
* restrict data to anthropometric variables
* and children with anthropometric information
*---------------------------------------------

keep  `idvars' sex ageday wgt hgt hgtmes uac headc
order `idvars' sex ageday wgt hgt hgtmes uac headc

drop if wgt==. & hgt==. & uac==. & headc==.
drop if wgt<=0 & hgt<=0 & uac<=0 & headc<=0


*---------------------------------------------
* Create some macro-specific variables needed
* to run -igrowup- (WHO Anthro)
*
* The -igrowup- macro requires 15 parameters.
* Refer to the documentation for details on this
* finicky macro.
*
* We don't have all of the measurements that
* it processes, so need to create empty
* variables that allow it to run
*---------------------------------------------

/// Indicate to the Stata compiler where the igrowup_standard.ado file is stored ***
adopath + "`whodir'"


gen str reflib="`whodir'"
lab var reflib "Directory of reference tables"

gen str datalib="`outdir'"
lab var datalib "Directory for datafiles"

gen str datalab="TEMPanthro"
lab var datalab "Working file"

gen str ageunit="days"
gen str measure="L" if hgtmes==2
replace measure="H" if hgtmes==1
replace measure=" " if measure == ""
label var measure "Height measured lying -L- or standing -H-"

* create missing variables so that macro will run
for any triskin subskin oedema: gen X = .

* set sampling wgtghts to negative to make the prevalence
* calculations blow up -- impossible to run that piece of 
* code w/o Stata SE b/c requires 10,000 variables
gen sw = -10


*---------------------------------------------
* Save a temporary dataset and run -igrowup-
* (note: igrowup adds variables to the data in
* memory and saves a copy dataset with the 
* suffix "_z_st.dta"). Dataset name must correspond
* to the "datalab" variable (defined in last chunk)
*---------------------------------------------

save "`outdir'/TEMPanthro", replace

#delimit;
igrowup_standard reflib datalib datalab 
sex ageday ageunit wgt hgt measure headc uac triskin subskin oedema sw;
#delimit cr


*---------------------------------------------
* Retrieve calculated output
* "_f" variables identify variables outside of
* reasonable bounds
*---------------------------------------------

use "`outdir'/TEMPanthro_z_st", clear


* rename Z-score variables
rename _zwei waz
rename _zlen haz
rename _zbmi bmiz
rename _zwfl whz
rename _zac  acz
rename _zhc  hcz

* rename Z-score extreme value flags
rename _fwei fwaz
rename _flen fhaz
rename _fbmi fbmiz
rename _fwfl fwhz
rename _fac  facz
rename _fhc  fhcz

label var fwaz  "=1 if (waz < -6 | waz > 5)"
label var fhaz  "=1 if (haz < -6 | haz > 6)"
label var fbmiz "=1 if (bmiz < -5 | bmiz > 5)"
label var fwhz  "=1 if (whz < -5 | whz > 5)"
label var facz  "=1 if (acz < -5 | acz > 5)"
label var fhcz  "=1 if (hcz < -5 | hcz > 5)"


*---------------------------------------------
* Drop temp variables used in the macro
*---------------------------------------------
drop reflib - sw _*


*---------------------------------------------
* Output an anthropometry dataset
*---------------------------------------------

label data "Anthropometric Z-scores"
sort `idvars'
codebook, c

save "`outdir'/`outfile'", replace

*---------------------------------------------
* erase temporary datasets
*---------------------------------------------

erase "`outdir'/tempanthro.dta"
erase "`outdir'/tempanthro_z_st.dta"
erase "`outdir'/tempanthro_z_st.xls"


end whoanthro
