
*---------------------------------------------
* Program    : 4 wsp-ASQ-bl.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 1.0 (2011-09-09)

A general program for the WSP IE to calculate
ASQ raw scores and Z-scores (by age group) for
BASELINE data.  Note that the ASQ form administration
differed between baseline and endline. For endline
score calculation, use 4 wsp-ASQ-el.do

The program requires a full set of variables 
from Module 25.

The program does not clean the datasets for
any potential errors in the data. It does 
flag and report the number of children with 
incomplete responses and the number of children 
to whom the incorrect module was delivered based 
on their calculated age at the time of the survey.
Finally, it flags and reports the number of children 
who have scores at the floor or ceiling of their age 
category.

Beyond Module 25, the program requires that the 
dataset include one additional variable be present 
in the dataset:
   ageday : child's age in days
   

The program creates a summary dataset with
identifiers along with the age and 
ASQ variables.  It creates the
dataset in the specified directory (see arguments)

Arguments:
idvars()  : Variable name list of Identifier variables to keep in the dataset. If running on panel data, then this must also include an indicator for survey round

outfile() : Text string for a directory/filename for the output dataset

* Note: this code follows the directions provided
* by Tricia Kariger in the files: 
"BASE SCORE COMM.SPS" and "FOLLOWUP ASQ SCORES_UPDATED 080111.txt"


*/
*---------------------------------------------



capture program drop wspASQbl
program define wspASQbl
version 10
	* this program calculates raw ASQ scores & Z-scores (by age category)
	* it is written to be run on WSP IE data, BASELINE SURVEY
	* it requires a full set of variables from module 25
	* it also requires the following variables be present in the dataset:
	*  ageday : child age in days

syntax, idvars(varlist) outfile(string)


di as res _n "--------------------------------" _n "* Begin wspASQbl (ASQ score calculation for BASELINE)" _n "--------------------------------"


local cntry = lower("`country'")

*---------------------------------------------
* Restrict the dataset to children w/ completed
* ASQ tests
*---------------------------------------------
di as res _n "Restricting to children w/ completed ASQ tests"
keep if g25_06 == 1

*---------------------------------------------
* Calculate child age in months
*---------------------------------------------
capture drop agem
gen agem = ageday / 30.4375
	label var agem "Age in months"
	


*---------------------------------------------
* Identify age group categories based on
* each child's calculated age.  
* Each age group took a different test (Form):
*
* FORM   AGE CAT   AGE MIN          AGE MAX
*-----------------------------------------------
* A  1   4 -  6 :  3 mo 16 days --  6 mo 15 days
* B  2   7 -  9 :  6 mo 16 days --  9 mo 15 days
* C  3  10 - 11 :  9 mo 16 days -- 11 mo 15 days
* D  4  12 - 13 : 11 mo 16 days -- 13 mo 15 days
* E  5  14 - 15 : 13 mo 16 days -- 15 mo 15 days
* F  6  16 - 17 : 15 mo 16 days -- 17 mo 15 days
* G  7  18 - 19 : 17 mo 16 days -- 19 mo 15 days
* H  8  20 - 21 : 19 mo 16 days -- 21 mo 15 days
* I  9  22 - 24 : 21 mo 16 days -- 24 mo 15 days
* J 10  25 - 30 : 24 mo 16 days -- 30 mo 15 days
* K 11  31 - 36 : 30 mo 16 days -- 36 mo 15 days
* L 12  37 - 42 : 36 mo 16 days -- 42 mo 15 days
* M 13  43 - 48 : 42 mo 16 days -- 48 mo 15 days
* N 14  49 - 60 : 48 mo 16 days -- 59 mo 31 days
*-----------------------------------------------

qui gen asqcat = g25_91
	label var asqcat "ASQ age category"
	label define asqcat 0 "not in range" 1 "4-6 mo" 2 "7-9 mo" 3 "10-11 mo" 4 "12-13 mo" 5 "14-15 mo" 6 "16-17 mo" 7 "18-19 mo" 8 "20-21 mo" 9 "22-24 mo" 10 "25-30 mo" 11 "31-36 mo" 12 "37-42 mo" 13 "43-48 mo" 14 "49-60 mo"
	label values asqcat asqcat

quietly {
	egen asqcatcalc = cut(agem), at(3.5,6.5,9.5,11.5,13.5,15.5,17.5,19.5,21.5,24.5,30.5,36.5,42.5,48.5,60) icodes
	replace asqcatcalc = asqcatcalc+1
	replace asqcatcalc = 0 if agem <= 3.5
	label var asqcatcalc "ASQ age category, calculated"
	label values asqcatcalc asqcat
}


*--------------------------------------------
* code chunk to deal with all missing ASSIGNED age categories
* (e.g., Peru endline as of May 27, 2011)
quietly {
	count if asqcat==.
	local catmiss = r(N)
	local totN = _N
	if (`catmiss'==`totN') local allmiss = "TRUE"
}

* confirm age ranges in the categories
di as res _n "Summary of age by ASSIGNED age categories"
if ("`allmiss'"=="") {
	table asqcat, c(freq min agem max agem) row	
}
else {
	di as res _n "WARNING : all ASSIGNED age categories are missing..." _n "Proceeding with CALCULATED age categories."
}
*--------------------------------------------

*--------------------------------------------
* code chunk to deal with baseline datasets
* that do not have a complete set of variables
* otherwise the code below will error out
quietly {

sum asqcat, meanonly
local catmax = r(max)
if (`catmax'==9) {
	* empty communication variables
	capture drop g25_07_34 - g25_07_47
	forvalues i = 34/47 {
		gen g25_07_`i' = .
	}
	* empty motor variables
	capture drop g25_08_35 - g25_08_44
	forvalues i = 35/44 {
		gen g25_08_`i' = .
	}
	* empty pers/soc variables
	capture drop g25_09_33 - g25_09_47
	forvalues i = 33/47 {
		gen g25_09_`i' = .
	}
}

}
*--------------------------------------------


di as res _n "Summary of age by CALCULATED age categories"
table asqcatcalc, c(freq min agem max agem) row	


*---------------------------------------------
* Recode system ASQ age category with calculated
* age category for children w/ missing age
* category
*---------------------------------------------
di as res _n "Recoding age category with calculated age for children w/ missing data "
replace asqcat = asqcatcalc if (asqcat==.|asqcat==0) & (asqcatcalc!=. & asqcatcalc!=0)

di as res _n "Final age cateogry distribution"
tab asqcat


*---------------------------------------------
* Flag children who were administered questions
* inconsistent with their calculated age
*---------------------------------------------

*count if (asqcat!= asqcatcalc) & (g25_06==1)
*tab asqcat asqcatcalc if asqcat!= asqcatcalc & g25_06==1, m
*list birthdt agem asqcat asqcatcalc if asqcat!= asqcatcalc & g25_06==1,  compress


gen asqcorrect = asqcat == asqcatcalc
	label define asqcorr 0 "Incorrect Qs" 1 "Correct Qs"
	label values asqcorrect asqcorr
	label var asqcorrect "Correct ASQ Qs administered?"
		
if ("`allmiss'"=="") {
	di as res _n "Summary of ASQ questionnaire administration"
	tab asqcorrect
}
else {
	qui replace asqcorrect = .
	di as res _n "WARNING : cannot evaluate ASQ administration accuraccy because all ASSIGNED age categories are missing."
}

*---------------------------------------------
* Drop children out of range (no ASQ data collected)
*---------------------------------------------
di as res _n "Drop children out of age range (no ASQ data collected)"
drop if asqcat==0
keep if asqcat!=.


*--------------------------------------------
* Recode scores to 0, 5, 10 for responses:
* 0 /  0 Not Yet
* 1 /  5 Sometimes
* 2 / 10 Yes
*
* -97 coded as missing
*
* NOTE: as of July 8, 2011 demonstration items ignored
*
*--------------------------------------------

quietly {

	* Communication scores (1 - 47)
	local clist "01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47"
	foreach i of local clist {
		gen int asqcom`i' = g25_07_`i' * 5
		replace asqcom`i' = . if ! inlist(g25_07_`i',0,1,2)
		local lab : var lab g25_07_`i'
		label var asqcom`i' `"`lab'"'
	}
	
	* Motor scores (1 - 44)
	local mlist "01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44"
	foreach i of local mlist {
		gen int asqmot`i' = g25_08_`i' * 5
		replace asqmot`i' = . if ! inlist(g25_08_`i',0,1,2)
		local lab : var lab g25_08_`i'
		label var asqmot`i' `"`lab'"'
	}
	
	* Personal / Social scores (1 - 47)
	* (note: no Q 28, this is not a typo)
	local plist "01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27   29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47"
	foreach i of local plist {
		gen int asqps`i' = g25_09_`i' * 5
		replace asqps`i' = . if ! inlist(g25_09_`i',0,1,2)
		local lab : var lab g25_09_`i'
		label var asqps`i' `"`lab'"'
	}

}


*--------------------------------------------
* Calculate raw scores
*
* Give children points for lower questions that
* they were not administered 
*
* This code follows the directions provided
* by Tricia Kariger in the files: 
* "BASE SCORE COMM.SPS" and "FOLLOWUP ASQ SCORES.txt"
*--------------------------------------------
quietly {

* Communication Scores
	gen ASQcomm = .
	label var ASQcomm "ASQ communication score"
	
	* FORM A
	replace ASQcomm = asqcom01+asqcom02+asqcom03+asqcom04+asqcom05+asqcom06+asqcom07+asqcom08+asqcom09+asqcom10+asqcom11+asqcom12+asqcom13 if (asqcat==1)
	
	* FORM B
	replace ASQcomm = 50+ asqcom06+asqcom07+asqcom08+asqcom09+asqcom10+asqcom11+asqcom12+asqcom13+asqcom14+asqcom15+asqcom16 if (asqcat==2)
	
	* FORM C
	replace ASQcomm = 110+ asqcom12+asqcom13+asqcom14+asqcom15+asqcom16+asqcom17+asqcom18+asqcom19 if (asqcat==3)
	
	* FORM D
	replace ASQcomm = 130+ asqcom14+asqcom15+asqcom16+asqcom17+asqcom18+asqcom19+asqcom20+asqcom21+asqcom22 if (asqcat==4)
	
	* FORM E
	replace ASQcomm = 160+ asqcom17+asqcom18+asqcom19+asqcom20+asqcom21+asqcom22+asqcom23+asqcom24 if (asqcat==5)
	
	* FORM F
	replace ASQcomm = 190+ asqcom20+asqcom21+asqcom22+asqcom23+asqcom24+asqcom25+asqcom26 if (asqcat==6)
	
	* FORM G
	replace ASQcomm = 220+ asqcom23+asqcom24+asqcom25+asqcom26+asqcom27+asqcom28 if (asqcat==7)
	
	* FORM H
	replace ASQcomm = 240+ asqcom25+asqcom26+asqcom27+asqcom28+asqcom29+asqcom30+asqcom31 if (asqcat==8)
	
	* FORM I
	replace ASQcomm = 260+ asqcom27+asqcom28+asqcom29+asqcom30+asqcom31+asqcom32+asqcom33 if (asqcat==9)
	
	* FORM J
	replace ASQcomm = 260+ asqcom27+asqcom28+asqcom29+asqcom30+asqcom31+asqcom32+asqcom33+asqcom34+asqcom35+asqcom36 if (asqcat==10)
	
	* FORM K
	* (note: Q 30 not administered in Form K -- credit given)
	replace ASQcomm = 270+ asqcom27+asqcom28+asqcom29+asqcom31+asqcom32+asqcom33+asqcom34+asqcom35+asqcom36+asqcom37+asqcom38+asqcom39 if (asqcat==11)
	
	* FORM L
	replace ASQcomm = 310+ asqcom32+asqcom33+asqcom34+asqcom35+asqcom36+asqcom37+asqcom38+asqcom39+asqcom40+asqcom41+asqcom42 if (asqcat==12)
	
	* FORM M
	replace ASQcomm = 330+ asqcom34+asqcom35+asqcom36+asqcom37+asqcom38+asqcom39+asqcom40+asqcom41+asqcom42+asqcom43+asqcom44 if (asqcat==13)
	
	* FORM N
	replace ASQcomm = 360+ asqcom37+asqcom38+asqcom39+asqcom40+asqcom41+asqcom42+asqcom43+asqcom44+asqcom45+asqcom46+asqcom47 if (asqcat==14)
	


* Motor Scores
	gen ASQmotor = .
	label var ASQmotor "ASQ motor score"
	
	* FORM A
	replace ASQmotor = asqmot01+asqmot02+asqmot03+asqmot04+asqmot05+asqmot06+asqmot07+asqmot08+asqmot09+asqmot10+asqmot11+asqmot12+asqmot13+asqmot14 if (asqcat==1)
	
	* FORM B
	replace ASQmotor = 60+ asqmot07+asqmot08+asqmot09+asqmot10+asqmot11+asqmot12+asqmot13+asqmot14+asqmot15+asqmot16+asqmot17 if (asqcat==2)
	
	* FORM C
	replace ASQmotor = 120+ asqmot13+asqmot14+asqmot15+asqmot16+asqmot17+asqmot18 if (asqcat==3)
	
	* FORM D
	replace ASQmotor = 140+ asqmot15+asqmot16+asqmot17+asqmot18+asqmot19+asqmot20+asqmot21 if (asqcat==4)
	
	* FORM E
	replace ASQmotor = 170+ asqmot18+asqmot19+asqmot20+asqmot21+asqmot22+asqmot23+asqmot24+asqmot25+asqmot26 if (asqcat==5)
	
	* FORM F
	replace ASQmotor = 200+ asqmot21+asqmot22+asqmot23+asqmot24+asqmot25+asqmot26+asqmot27+asqmot28 if (asqcat==6)
	
	* FORM G
	replace ASQmotor = 230+ asqmot24+asqmot25+asqmot26+asqmot27+asqmot28+asqmot29+asqmot30 if (asqcat==7)
	
	* FORM H
	replace ASQmotor = 250+ asqmot26+asqmot27+asqmot28+asqmot29+asqmot30+asqmot31 if (asqcat==8)
	
	* FORM I
	replace ASQmotor = 270+ asqmot28+asqmot29+asqmot30+asqmot31+asqmot32+asqmot33+asqmot34 if (asqcat==9)

	* FORM J
	replace ASQmotor = 270+ asqmot28+asqmot29+asqmot30+asqmot31+asqmot32+asqmot33+asqmot34+asqmot35+asqmot36 if (asqcat==10)
	
	* FORM K
	replace ASQmotor = 270+ asqmot28+asqmot29+asqmot30+asqmot31+asqmot32+asqmot33+asqmot34+asqmot35+asqmot36+asqmot37+asqmot38+asqmot39 if (asqcat==11)
	
	* FORM L
	replace ASQmotor = 300+ asqmot31+asqmot32+asqmot33+asqmot34+asqmot35+asqmot36+asqmot37+asqmot38+asqmot39+asqmot40+asqmot41 if (asqcat==12)
	
	* FORM M
	replace ASQmotor = 330+ asqmot34+asqmot35+asqmot36+asqmot37+asqmot38+asqmot39+asqmot40+asqmot41+asqmot42+asqmot43 if (asqcat==13)
	
	* FORM N
	replace ASQmotor = 350+ asqmot36+asqmot37+asqmot38+asqmot39+asqmot40+asqmot41+asqmot42+asqmot43+asqmot44 if (asqcat==14)
	

* Personal / Social Scores
	* (NOTE Q 28 not administred in this study. No credit given for that Q in any score)
	gen ASQps = .
	label var ASQps "ASQ personal/social score"
	
	* FORM A
	replace ASQps = asqps01+asqps02+asqps03+asqps04+asqps05+asqps06+asqps07+asqps08+asqps09+asqps10+asqps11 if (asqcat==1)
	
	* FORM B
	replace ASQps = 50+ asqps06+asqps07+asqps08+asqps09+asqps10+asqps11+asqps12+asqps13+asqps14+asqps15+asqps16 if (asqcat==2)
	
	* FORM C
	replace ASQps = 110+ asqps12+asqps13+asqps14+asqps15+asqps16+asqps17+asqps18+asqps19+asqps20 if (asqcat==3)
	
	* FORM D
	replace ASQps = 130+ asqps14+asqps15+asqps16+asqps17+asqps18+asqps19+asqps20+asqps21+asqps22 if (asqcat==4)
	
	* FORM E
	replace ASQps = 160+ asqps17+asqps18+asqps19+asqps20+asqps21+asqps22+asqps23+asqps24 if (asqcat==5)
	
	* FORM F
	replace ASQps = 180+ asqps19+asqps20+asqps21+asqps22+asqps23+asqps24+asqps25+asqps26 if (asqcat==6)
	
	* FORM G
	replace ASQps = 220+ asqps23+asqps24+asqps25+asqps26+asqps27 if (asqcat==7)
	
	* FORM H
	* (Note: Q 28 not administered, no credit given)
	replace ASQps = 240+ asqps25+asqps26+asqps27+asqps29+asqps30+asqps31+asqps32 if (asqcat==8)
	
	* FORM I
	* (Note: Q 28 not administered, no credit given)
	replace ASQps = 260+ asqps27+asqps29+asqps30+asqps31+asqps32 if (asqcat==9)
	
	* FORM J
	* (Note: Q 28 not administered, no credit given)
	replace ASQps = 260+ asqps27+asqps29+asqps30+asqps31+asqps32+asqps33+asqps34+asqps35+asqps36+asqps37+asqps38 if (asqcat==10)
	
	* FORM K
	* (Note: Q 28 not administered, no credit given)
	* (note Q 31 not administered in FORM K -- credit given)
	replace ASQps = 270+ asqps27+asqps29+asqps30+asqps32+asqps33+asqps34+asqps35+asqps36+asqps37+asqps38+asqps39 if (asqcat==11)
	
	* FORM L
	* (Note: Q 28 not administered, no credit given)
	replace ASQps = 300+ asqps32+asqps33+asqps34+asqps35+asqps36+asqps37+asqps38+asqps39+asqps40+asqps41 if (asqcat==12)
	
	* FORM M
	* (Note: Q 28 not administered, no credit given)
	replace ASQps = 320+ asqps34+asqps35+asqps36+asqps37+asqps38+asqps39+asqps40+asqps41+asqps42+asqps43+asqps44+asqps45 if (asqcat==13)
	
	* FORM N
	* (Note: Q 28 not administered, no credit given)
	replace ASQps = 350+ asqps37+asqps38+asqps39+asqps40+asqps41+asqps42+asqps43+asqps44+asqps45+asqps46+asqps47 if (asqcat==14)

}

*--------------------------------------------
* If a child has a missing value for any item
* in their question set, set that child's 
* score to missing (this scenario should not 
* occur frequently in the data for completed interviews)
* 
*--------------------------------------------
quietly {

* Communication Scores

	* FORM A
	replace ASQcomm = . if (asqcom01==.|asqcom02==.|asqcom03==.|asqcom04==.|asqcom05==.|asqcom06==.|asqcom07==.|asqcom08==.|asqcom09==.|asqcom10==.|asqcom11==.|asqcom12==.|asqcom13==.) & (asqcat==1)
	
	* FORM B
	replace ASQcomm = . if (asqcom06==.|asqcom07==.|asqcom08==.|asqcom09==.|asqcom10==.|asqcom11==.|asqcom12==.|asqcom13==.|asqcom14==.|asqcom15==.|asqcom16==.) & (asqcat==2)
	
	* FORM C
	replace ASQcomm = . if (asqcom12==.|asqcom13==.|asqcom14==.|asqcom15==.|asqcom16==.|asqcom17==.|asqcom18==.|asqcom19==.) & (asqcat==3)

	* FORM D
	replace ASQcomm = . if (asqcom14==.|asqcom15==.|asqcom16==.|asqcom17==.|asqcom18==.|asqcom19==.|asqcom20==.|asqcom21==.|asqcom22==.) & (asqcat==4)
	
	* FORM E
	replace ASQcomm = . if (asqcom17==.|asqcom18==.|asqcom19==.|asqcom20==.|asqcom21==.|asqcom22==.|asqcom23==.|asqcom24==.) & (asqcat==5)
	
	* FORM F
	replace ASQcomm = . if (asqcom20==.|asqcom21==.|asqcom22==.|asqcom23==.|asqcom24==.|asqcom25==.|asqcom26==.) & (asqcat==6)

	* FORM G
	replace ASQcomm = . if (asqcom23==.|asqcom24==.|asqcom25==.|asqcom26==.|asqcom27==.|asqcom28==.) & (asqcat==7)
	
	* FORM H
	replace ASQcomm = . if (asqcom25==.|asqcom26==.|asqcom27==.|asqcom28==.|asqcom29==.|asqcom30==.|asqcom31==.) & (asqcat==8)
	
	* FORM I
	replace ASQcomm = . if (asqcom27==.|asqcom28==.|asqcom29==.|asqcom30==.|asqcom31==.|asqcom32==.|asqcom33==.) & (asqcat==9)
	
	* FORM J
	replace ASQcomm = . if (asqcom27==.|asqcom28==.|asqcom29==.|asqcom30==.|asqcom31==.|asqcom32==.|asqcom33==.|asqcom34==.|asqcom35==.|asqcom36==.) & (asqcat==10)
	
	* FORM K
	* (note: Q 30 not administered in Form K -- credit given)
	replace ASQcomm = . if (asqcom27==.|asqcom28==.|asqcom29==.|asqcom31==.|asqcom32==.|asqcom33==.|asqcom34==.|asqcom35==.|asqcom36==.|asqcom37==.|asqcom38==.|asqcom39==.) & (asqcat==11)
	
	* FORM L
	replace ASQcomm = . if (asqcom32==.|asqcom33==.|asqcom34==.|asqcom35==.|asqcom36==.|asqcom37==.|asqcom38==.|asqcom39==.|asqcom40==.|asqcom41==.|asqcom42==.) & (asqcat==12)
	
	* FORM M
	replace ASQcomm = . if (asqcom34==.|asqcom35==.|asqcom36==.|asqcom37==.|asqcom38==.|asqcom39==.|asqcom40==.|asqcom41==.|asqcom42==.|asqcom43==.|asqcom44==.) & (asqcat==13)
	
	* FORM N
	replace ASQcomm = . if (asqcom37==.|asqcom38==.|asqcom39==.|asqcom40==.|asqcom41==.|asqcom42==.|asqcom43==.|asqcom44==.|asqcom45==.|asqcom46==.|asqcom47==.) & (asqcat==14)
	


* Motor Scores
	
	* FORM A
	replace ASQmotor = . if (asqmot01==.|asqmot02==.|asqmot03==.|asqmot04==.|asqmot05==.|asqmot06==.|asqmot07==.|asqmot08==.|asqmot09==.|asqmot10==.|asqmot11==.|asqmot12==.|asqmot13==.|asqmot14==.) & (asqcat==1)
	
	* FORM B
	replace ASQmotor = . if (asqmot07==.|asqmot08==.|asqmot09==.|asqmot10==.|asqmot11==.|asqmot12==.|asqmot13==.|asqmot14==.|asqmot15==.|asqmot16==.|asqmot17==.) & (asqcat==2)
	
	* FORM C
	replace ASQmotor = . if (asqmot13==.|asqmot14==.|asqmot15==.|asqmot16==.|asqmot17==.|asqmot18==.) & (asqcat==3)
	
	* FORM D
	replace ASQmotor = . if (asqmot15==.|asqmot16==.|asqmot17==.|asqmot18==.|asqmot19==.|asqmot20==.|asqmot21==.) & (asqcat==4)
	
	* FORM E
	replace ASQmotor = . if (asqmot19==.|asqmot20==.|asqmot21==.|asqmot22==.|asqmot23==.|asqmot24==.|asqmot25==.|asqmot26==.) & (asqcat==5)
	
	* FORM F
	replace ASQmotor = . if (asqmot21==.|asqmot22==.|asqmot23==.|asqmot24==.|asqmot25==.|asqmot26==.|asqmot27==.|asqmot28==.) & (asqcat==6)
	
	* FORM G
	replace ASQmotor = . if (asqmot24==.|asqmot25==.|asqmot26==.|asqmot27==.|asqmot28==.|asqmot29==.|asqmot30==.) & (asqcat==7)
	
	* FORM H
	replace ASQmotor = . if (asqmot26==.|asqmot27==.|asqmot28==.|asqmot29==.|asqmot30==.|asqmot31==.) & (asqcat==8)
	
	* FORM I
	replace ASQmotor = . if (asqmot28==.|asqmot29==.|asqmot30==.|asqmot31==.|asqmot32==.|asqmot33==.|asqmot34==.) & (asqcat==9)
	
	* FORM J
	replace ASQmotor = . if (asqmot28==.|asqmot29==.|asqmot30==.|asqmot31==.|asqmot32==.|asqmot33==.|asqmot34==.|asqmot35==.|asqmot36==.) & (asqcat==10)
	
	* FORM K
	replace ASQmotor = . if (asqmot28==.|asqmot29==.|asqmot30==.|asqmot31==.|asqmot32==.|asqmot33==.|asqmot34==.|asqmot35==.|asqmot36==.|asqmot37==.|asqmot38==.|asqmot39==.) & (asqcat==11)
	
	* FORM L
	replace ASQmotor = . if (asqmot31==.|asqmot32==.|asqmot33==.|asqmot34==.|asqmot35==.|asqmot36==.|asqmot37==.|asqmot38==.|asqmot39==.|asqmot40==.|asqmot41==.) & (asqcat==12)
	
	* FORM M
	replace ASQmotor = . if (asqmot34==.|asqmot35==.|asqmot36==.|asqmot37==.|asqmot38==.|asqmot39==.|asqmot40==.|asqmot41==.|asqmot42==.|asqmot43==.) & (asqcat==13)
	
	* FORM N
	replace ASQmotor = . if (asqmot36==.|asqmot37==.|asqmot38==.|asqmot39==.|asqmot40==.|asqmot41==.|asqmot42==.|asqmot43==.|asqmot44==.) & (asqcat==14)


* Personal / Social Scores

	* FORM A
	replace ASQps = . if (asqps01==.|asqps02==.|asqps03==.|asqps04==.|asqps05==.|asqps06==.|asqps07==.|asqps08==.|asqps09==.|asqps10==.|asqps11==.) &  (asqcat==1)
	
	* FORM B
	replace ASQps = . if (asqps06==.|asqps07==.|asqps08==.|asqps09==.|asqps10==.|asqps11==.|asqps12==.|asqps13==.|asqps14==.|asqps15==.|asqps16==.) &  (asqcat==2)
	
	* FORM C
	replace ASQps = . if (asqps12==.|asqps13==.|asqps14==.|asqps15==.|asqps16==.|asqps17==.|asqps18==.|asqps19==.|asqps20==.) &  (asqcat==3)
	
	* FORM D
	replace ASQps = . if (asqps14==.|asqps15==.|asqps16==.|asqps17==.|asqps18==.|asqps19==.|asqps20==.==.|asqps21==.|asqps22==.) &  (asqcat==4)
	
	* FORM E
	replace ASQps = . if (asqps17==.|asqps18==.|asqps19==.|asqps20==.==.|asqps21==.|asqps22==.|asqps23==.|asqps24==.) &  (asqcat==5)
	
	* FORM F
	replace ASQps = . if (asqps19==.|asqps20==.==.|asqps21==.|asqps22==.|asqps23==.|asqps24==.|asqps25==.|asqps26==.) &  (asqcat==6)

	* FORM G
	replace ASQps = . if (asqps23==.|asqps24==.|asqps25==.|asqps26==.|asqps27==.) &  (asqcat==7)
	
	* FORM H
	* (Note: Q 28 not administered)
	replace ASQps = . if (asqps25==.|asqps26==.|asqps27==.|asqps29==.|asqps30==.|asqps31==.|asqps32==.) &  (asqcat==8)

	* FORM I
	* (Note: Q 28 not administered)
	replace ASQps = . if (asqps27==.|asqps29==.|asqps30==.|asqps31==.|asqps32==.) &  (asqcat==9)
	
	* FORM J
	* (Note: Q 28 not administered)
	replace ASQps = . if (asqps27==.|asqps29==.|asqps30==.|asqps31==.|asqps32==.|asqps33==.|asqps34==.|asqps35==.|asqps36==.|asqps37==.|asqps38==.) &  (asqcat==10)
	
	* FORM K
	* (Note: Q 28 not administered)
	* (Note: Q 31 not administered in FORM K -- credit given)
	replace ASQps = . if (asqps27==.|asqps29==.|asqps30==.|asqps32==.|asqps33==.|asqps34==.|asqps35==.|asqps36==.|asqps37==.|asqps38==.|asqps39==.) &  (asqcat==11)
	
	* FORM L
	replace ASQps = . if (asqps32==.|asqps33==.|asqps34==.|asqps35==.|asqps36==.|asqps37==.|asqps38==.|asqps39==.|asqps40==.|asqps41==.) &  (asqcat==12)
	
	* FORM M
	replace ASQps = . if (asqps34==.|asqps35==.|asqps36==.|asqps37==.|asqps38==.|asqps39==.|asqps40==.|asqps41==.|asqps42==.|asqps43==.|asqps44==.|asqps45==.) &  (asqcat==13)
	
	* FORM N
	replace ASQps = . if (asqps37==.|asqps38==.|asqps39==.|asqps40==.|asqps41==.|asqps42==.|asqps43==.|asqps44==.|asqps45==.|asqps46==.|asqps47==.) &  (asqcat==14)

}
*--------------------------------------------
* Count children who have partially complete data
*--------------------------------------------
qui egen totcom = rowtotal(asqcom01-asqcom47), missing
qui egen totmot = rowtotal(asqmot01-asqmot44), missing
qui egen totps  = rowtotal(asqps01 -asqps47), missing

quietly {
	gen comcomp = (totcom>=0 & totcom<.) & (ASQcomm==.)
		replace comcomp = 2 if totcom==.
		label var comcomp "ASQ comm Qs completion status"
	gen motcomp = (totmot>=0 & totmot<.) & (ASQmotor==.)
		replace motcomp = 2 if totmot==.
		label var motcomp "ASQ motor Qs completion status"
	gen pscomp = (totps>=0  & totps <.) & (ASQps==.)
		replace pscomp = 2 if totps ==.
		label var pscomp "ASQ pers/soc Qs completion status"
	replace comcomp = comcomp+1
	replace motcomp = motcomp+1
	replace pscomp = pscomp+1
}
	
drop totcom totmot totps

label define asqcomp 1 "Complete" 2 "Partially complete" 3 "No record"
label values comcomp asqcomp
label values motcomp asqcomp
label values pscomp asqcomp
	
* N and % for partially complete data
di as res _n "Summary of item list completion status"
tab1 comcomp motcomp pscomp


*--------------------------------------------
* Identify children at the floor or 
* ceiling of their age category
*--------------------------------------------
quietly {

	* Communication Scores
	gen mincom = .
	gen maxcom = .
		label var mincom "Minimum ASQ commun score for age cat"
		label var maxcom "Maximum ASQ commun score for age cat"
	local cmins "  0  50 110 130 160 190 220 240 260 260 270 310 330 360"
	local cmaxs "130 160 190 220 240 260 280 310 330 360 390 420 440 470"
	forvalues i = 1/14 {
		local cmin : word `i' of `cmins'
		local cmax : word `i' of `cmaxs'
		replace mincom = `cmin' if asqcat==`i'
		replace maxcom = `cmax' if asqcat==`i'
	}
	
	* Motor Scores
	gen minmot = .
	gen maxmot = .
		label var minmot "Minimum ASQ motor score for age cat"
		label var maxmot "Maximum ASQ motor score for age cat"
	local mmins "  0  60 120 140 170 200 230 250 270 270 270 300 330 350"
	local mmaxs "140 170 180 210 260 280 300 310 340 360 390 410 430 440"
	forvalues i = 1/14 {
		local mmin : word `i' of `mmins'
		local mmax : word `i' of `mmaxs'
		replace minmot = `mmin' if asqcat==`i'
		replace maxmot = `mmax' if asqcat==`i'
	}
	
	* Personal / Social Scores
	gen minps = .
	gen maxps = .
		label var minps "Minimum ASQ pers/soc score for age cat"
		label var maxps "Maximum ASQ pers/soc score for age cat"
	local pmins "  0  50 110 130 160 180 220 240 260 260 270 300 320 350"
	local pmaxs "110 160 200 220 240 260 270 310 310 370 380 400 440 460"
	forvalues i = 1/14 {
		local pmin : word `i' of `pmins'
		local pmax : word `i' of `pmaxs'
		replace minps = `pmin' if asqcat==`i'
		replace maxps = `pmax' if asqcat==`i'
	}
	
	
	* identify floor and ceiling observations
	gen comfloor = (ASQcomm==mincom)
		replace comfloor = . if ASQcomm==.
		label var comfloor "At floor of ASQ comm category"
	gen comceil = (ASQcomm==maxcom)
		replace comceil = . if ASQcomm==.
		label var comceil "At ceiling of ASQ comm age cat"
		
	gen motfloor = (ASQmotor==minmot)
		replace motfloor = . if ASQmotor==.
		label var motfloor "At floor of ASQ motor age cat"
	gen motceil = (ASQmotor==maxmot)
		replace motceil = . if ASQmotor==.
		label var motceil "At ceiling of ASQ motor age cat"
	
	gen psfloor = (ASQps==minps)
		replace psfloor = . if ASQps==.
		label var psfloor "At floor of ASQ pers/soc age cat"
	gen psceil = (ASQps==maxps)
		replace psceil = . if ASQmotor==.
		label var psceil "At ceiling of ASQ pers/soc age cat"
}

* Summarize N and % at the floor/ceiling of each domain
di as res _n "Summary of N and % at the floor/ceiling of each domain"
tab1 comfloor comceil motfloor motceil psfloor psceil


*--------------------------------------------
* Calculate ASQ Z-scores by age group
*--------------------------------------------
quietly {
	
	sort asqcat
	local vlist "ASQcomm ASQmotor ASQps"
	foreach var of varlist `vlist' {
		by asqcat: egen mu = mean(`var')
		by asqcat: egen sd = sd(`var')
		gen z`var'= (`var'-mu)/sd
		drop mu sd
	}
	
	label var zASQcomm  "Z score: ASQ communication"
	label var zASQmotor "Z score: ASQ motor"
	label var zASQps    "Z score: ASQ personal/social"
}

di as res _n "Summary of Raw and Z ASQ scores"
sum *ASQ*, sep(3)

keep `idvars' ageday agem asqcat asqcatcalc asqcorrect comcomp motcomp pscomp mincom maxcom comfloor comceil minmot maxmot motfloor motceil minps maxps psfloor psceil *ASQ* g25*

order `idvars' ageday agem asqcat asqcatcalc asqcorrect comcomp motcomp pscomp mincom maxcom comfloor comceil minmot maxmot motfloor motceil minps maxps psfloor psceil ASQcomm ASQmotor ASQps zASQcomm zASQmotor zASQps

di as res _n "Compressing dataset..."
compress asqcat - zASQps



*---------------------------------------------
* Output an ASQ dataset
*---------------------------------------------

label data "Ages and Stages Questionnaire Scores, Baseline"
sort `idvars'
codebook `idvars' ageday - zASQps, c

save "`outfile'", replace


di as res _n "--------------------------------" _n "* End wspASQbl" _n "--------------------------------"
end wspASQbl


