
*---------------------------------------------
* Program    : 5 wsp-anemia.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 2.0 (2011-09-09)

Identify children who are anemic in the WSP study. 
If altitude adjustments are required (e.g. Peru),
then this program assumes that you provide it with
the altitude-adjusted Hb levels.  In the endline
dataset, these are recorded in the variable 
g33_14b.

The program assumes that the hemoglobin (Hb) measurements
are in grams per deciliter (g/dl).  The thresholds are 
reported in grams per liter (g/l). There are 10 deciliters
per liter.

For anemia, elevation adjustment is recommended for
populations living > 1000m.  See the following WHO
recommendations for details:
http://www.who.int/vmnis/indicators/haemoglobin.pdf

Anemia is defined for children 6 - 59 months of age as
< 110 g/l.  The categories of Mild/Moderate/Severe anemia
are defined as:

Mild     : Hb 100 - 109 g/l
Moderate : Hb  70 -  99  g/l
Severe   : Hb <70  g/l

This program creates two variables, one that flags
anemic children and a second that categorizes them into four
categories: non-anemic, mildly anemic, moderately anemic, severely anemic.

If Hb levels are above 200 g/l, then the anemia indicators are set to missing.
Levels > 200 are extreme.

Children with missing values for the anemia measurement are coded as missing. The original Hb variables are retained in the output dataset.

Arguments:
idvars()  : Variable name list of Identifier variables to keep in the dataset. If running on panel data, then this must also include an indicator for survey round

hbvar()   : Variable name of the hemoglobin level (potentially adjusted for altitude).

outfile() : Text string for a directory/filename for the output dataset


*/
*---------------------------------------------



capture program drop wspanemia
program define wspanemia
version 10
	* this program calculates child symptoms and acute illness
	* it is written to be run on WSP IE endline data
	* it requires variables from module 33

syntax, idvars(varlist) hbvar(varlist max=1) outfile(string)


di as res _n "--------------------------------" _n "* Begin wspanemia" _n "--------------------------------"

*---------------------------------------------
* Calculate anmeia status
*---------------------------------------------

gen Hblevel = `hbvar' * 10
	label var Hblevel "Hb level (g/l) used for anemia classification"

gen byte anemic = Hblevel < 110
	replace anemic = . if (Hblevel==.) | (Hblevel <= 0) | (Hblevel>200)
	label define anemic 1 "Anemic" 0 "Not Anemic"
	label values anemic anemic
	label var anemic "Anemic: Hb < 110 g/l"
	
gen anemia = 1 if Hblevel >= 110
	replace anemia = 2 if Hblevel >=100 & Hblevel <= 109
	replace anemia = 3 if Hblevel >=70  & Hblevel <=  99
	replace anemia = 4 if Hblevel < 70
	replace anemia = . if (Hblevel==.) | (Hblevel <= 0) | (Hblevel>200)
	label define anemia 1 "Non-anemic, Hb >= 110 g/l" 2 "Mild anemia, Hb 100 - 109 g/l" 3 "Moderate anemia, Hb 70 - 99 g/l" 4 "Severe anemia, Hb < 70 g/l"
	label values anemia anemia
	label var anemia "Anemia status"

di as res _n "Summary of Anemia Status"
tab anemia



di as res _n "Compressing dataset..."
keep `idvars' Hblevel anemia anemic
order `idvars'
compress 

*---------------------------------------------
* Output an anemia dataset
*---------------------------------------------

label data "Anemia status and Hb measures"
sort `idvars'
codebook, c

save "`outfile'", replace


di as res _n "--------------------------------" _n "* End wspanemia" _n "--------------------------------"
end wspillness


