
*---------------------------------------------
* Program    : 7 wsp-sanitation.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 2.0 (2011-09-09)

A general program to calculate a derived
sanitation variables for the WSP IE endline datasets.
Documentation / references are cited below in the code.

The program requires the full set of variables from Module 9.

Beyond Module 9, the program requires that the 
dataset include one additional variable:
   survid : survey ID, equal to 1 for baseline and 2 for endline


Arguments:
idvars()    : Variable name list of identifier variables (should uniquely identify households)

outfile()   : Text string for a directory/filename for the output dataset


*/
*---------------------------------------------

capture program drop wspsanitation
program define wspsanitation
version 10

syntax , idvars(varlist) outfile(string)


*---------------------------------------------
* Identify JMP improved sanitation
* JMP Core Questions on Drinking Water and Sanitation for HH Surveys
* www.who.int/water_sanitation_health/monitoring/household_surveys/en/index.html
*

gen byte JMPsan = inlist(g09_01,1,2,3,6,7,8)
	replace JMPsan = . if inlist(g09_01,-99,.)
	label define JMPsan 0 "Unimproved Sanitation" 1 "Improved Sanitation"
	label values JMPsan JMPsan
	label var JMPsan "JMP Improved Sanitation"
*---------------------------------------------

*---------------------------------------------
* Identify JMP proper feces disposal
* proper is latrine/burried (options 2,4)
* www.who.int/water_sanitation_health/monitoring/household_surveys/en/index.html
*

gen byte JMPfeces = (g09_22_2==1|g09_22_4==1)
	egen _tmp = rowtotal(g09_22*), missing
	replace JMPfeces = . if _tmp==.
	drop _tmp
	label var JMPfeces "JMP correct child feces disposal"
	label define JMPfeces 0 "Incorrect" 1 "Correct"
	label values JMPfeces JMPfeces
*---------------------------------------------


*---------------------------------------------
* Identify toilets in the household or yard
*

gen byte hhtoilet = inlist(g09_09,1,2)
	replace hhtoilet = . if g09_09 == .
	label var hhtoilet "Toilet located in HH or yard"
*---------------------------------------------


*---------------------------------------------
* Reported HH open defecation practices
*---------------------------------------------

* Men practice daily OD
gen byte ODmen = (g09_23_a==1)
	replace ODmen = . if survid==1
	label define YN 1 "Yes" 0 "No"
	label values ODmen YN
	label var ODmen "Men in HH practice daily open def."

* Women practice daily OD
gen byte ODwom = (g09_23_b==1)
	replace ODwom = . if survid==1
	label values ODwom YN
	label var ODwom "Women in HH practice daily open def."

* Children < 5 practice daily OD
gen byte ODch = (g09_23_c==1)
	replace ODch = . if survid==1
	label values ODch YN
	label var ODch "Children < 5y in HH practice daily open def."


*---------------------------------------------
* Reported Community open defecation practices
*---------------------------------------------

* Men practice daily OD
gen byte ODmencom = (g09_28_a==1)
	replace ODmencom = . if survid==1
	label values ODmencom YN
	label var ODmencom "Men in Community practice daily open def."

* Women practice daily OD
gen byte ODwomcom = (g09_28_b==1)
	replace ODwomcom = . if survid==1
	label values ODwomcom YN
	label var ODwomcom "Women in Community practice daily open def."

* Children < 5 practice daily OD
gen byte ODchcom = (g09_28_c==1)
	replace ODchcom = . if survid==1
	label values ODchcom YN
	label var ODchcom "Children < 5y in Community practice daily open def."
	
* Suggested modification for India 
* in lieu of the above 3 variables (separate questions apparently not asked)
* gen byte ODhhcom = (g09_28==1)
*	replace ODhhcom = . if survid==1
*	label values ODhhcom YN
*	label var ODhhcom "Other HH in Community practice daily open def."


* Child feces disposal
gen byte comfeces = (g09_29==1)
	replace comfeces = . if survid==1
	label values comfeces YN
	label var comfeces "Child feces are often disposed in the yard/surrounding/community in your neighborhood/river"



*---------------------------------------------
* Output the dataset with the added variables
*---------------------------------------------

di as res _n "Compressing and saving data..."
keep `idvars' JMPsan - comfeces
compress

label data "Standard Sanitation Variables"

save "`outfile'", replace

codebook, c

end wspsanitation




